DataEvent class

Constructors

DataEvent({required DataEventType type, required DataItem dataItem, required bool isDataValid})
DataEvent.fromJson(Map<String, dynamic> json)
factory

Properties

dataItem → DataItem
The DataItem associated with this event.
final
hashCode → int
The hash code for this object.
no setterinherited
isDataValid → bool
A bool value indicating if this data is valid
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DataEventType
The DataEventType enum value indicating which type of event is it. Can be DataEventType.changed or DataEventType.deleted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited